@@ -100,11 +100,11 @@ void composition_game_cross_clicked (TangleButton* tanglebutton, gpointer none){
 	*/
 	gboolean pop_menu = TRUE;
 
-	if (tangle_widget_get_n_children(TANGLE_WIDGET(tangle_wrapper_actor_get_wrapped(TANGLE_WRAPPER_ACTOR(current_theme->bottom_track_view)))) ==0) { //track1 empty
+	if (tangle_widget_get_n_children(TANGLE_WIDGET(current_theme->bottom_track_view)) ==0) { //track1 empty
 		if  (current_theme->upper_track_view == NULL)  //only one track
 			pop_menu = FALSE;
 		else  //There are two tracks
-			if (tangle_widget_get_n_children(TANGLE_WIDGET(tangle_wrapper_actor_get_wrapped(TANGLE_WRAPPER_ACTOR(current_theme->upper_track_view)))) ==0) { //track2 empty
+			if (tangle_widget_get_n_children(TANGLE_WIDGET(current_theme->upper_track_view)) ==0) { //track2 empty
 				pop_menu = FALSE;
 			}
 		}
