@@ -28,7 +28,7 @@ void themeselection_theme_clicked(TangleAction *action, GObject *source, const g
 	const gchar* name = clutter_actor_get_name(CLUTTER_ACTOR(source));
 	
 	//subthemes are 1,2,3.
-	int variation = 3; //(rand () % 3) + 1; TESTING
+	int variation = (rand () % 3) + 1;
 	printf("Random variation is '%d'\n",variation);
 	
 	composition_game_start_theme(name,variation,jammo_get_actor_by_id("themeselection-view"));
