@@ -15,6 +15,7 @@
 #include "../../meam/jammo-sample.h"
 #include "chum.h"
 
+#include "../pen_gesture/login_screen.h"
 
 
 
@@ -24,10 +25,15 @@ static void finalize_welcome(void) {
 	if ((actor = jammo_get_actor_by_id("welcome-view"))) {
 		tangle_actor_hide_animated(TANGLE_ACTOR(actor));
 	}
+
+	//Do not go to main-menu, but login_screen
+	login_screen();
+	/*
 	if ((actor = jammo_get_actor_by_id("main-menu-view"))) {
 		clutter_actor_show(actor);
 		clutter_actor_queue_relayout(clutter_actor_get_parent(actor));
 	}
+	*/
 
 	//Set default language for singing game
 	// It also affects first flag showed
@@ -81,7 +87,9 @@ void welcome_door_clicked(TangleAction *action, GObject *source, const gchar *tr
 
 	//Show version number: defined in configure.ac
 	gchar* version = g_strdup_printf("JamMo version:%s",VERSION);
-	ClutterActor* version_label = clutter_text_new_with_text ("Luxi Mono 18",version); 
+	ClutterActor* version_label = clutter_text_new_with_text ("Luxi Mono 38",version);
+	ClutterColor text_color = { 255, 255, 0, 255 };
+	clutter_text_set_color(CLUTTER_TEXT(version_label), &text_color);
 	g_free(version);
 	actor = jammo_get_actor_by_id("welcome-view");
 	clutter_container_add_actor (CLUTTER_CONTAINER (actor), version_label);
