@@ -483,8 +483,8 @@ static void instrument_gui_on_sequencer_stopped(JammoSequencer* sequencer, gpoin
 
 			//take all note-events from track
 			GList* list= jammo_instrument_track_get_event_list(JAMMO_INSTRUMENT_TRACK(track));
-			//Clean track
-			jammo_instrument_track_set_event_list(JAMMO_INSTRUMENT_TRACK(track),NULL);
+			//Clean midi-track-view and track inside it
+			jammo_miditrack_view_remove_all(static_jammo_miditrack_view);
 			//And put them back via miditrack_view
 			jammo_miditrack_view_add_event_list(static_jammo_miditrack_view,list);
 		}
@@ -507,9 +507,9 @@ a) instrument_gui_start(JAMMO_MIDITRACK_VIEW(track->track_view),sequencer, NULL)
 or
 b) instrument_gui_start(NULL,sequencer, TANGLE_WIDGET(track->track_view));
 */
-void instrument_gui_start (JammoMiditrackView* miditrack_view, JammoSequencer* parameter_sequencer, TangleWidget* slider_container)
+void instrument_gui_start (JammoMiditrackView* miditrack_view, TangleWidget* slider_container)
 {
-	static_sequencer = parameter_sequencer;
+	static_sequencer = JAMMO_SEQUENCER(jammo_get_object_by_id("fullsequencer-the-sequencer"));
 	handler_for_sequencer_stop = g_signal_connect(static_sequencer, "stopped", G_CALLBACK(instrument_gui_on_sequencer_stopped), NULL);
 
 	ClutterActor* mainview;
