@@ -443,8 +443,11 @@ static gboolean first_time = TRUE;
 
 /* JSON callback when sequencer-view is showed*/
 void start_sequencer_full_sequencer (TangleAction *action, GObject *source, const gchar *trigger, TangleProperties *properties){
-	if (first_time)
-		start_sequencer("/opt/jammo/seq.json"); //This is default
+	if (first_time){
+		gchar* filename = tangle_lookup_filename("seq.json"); //This is default
+		start_sequencer(filename);
+		g_free(filename);
+	}
 	first_time=FALSE;
 }
 
@@ -454,6 +457,8 @@ This actor is visible when starting jammo_get_actor_by_id("fullsequencer-view");
 void start_sequencer(gpointer filename)
 {
 	printf("Starting sequencer GUI\n");
+	ClutterAction* action = tangle_actor_get_action_by_type(jammo_get_actor_by_id("fullsequencer-view-container"), TANGLE_TYPE_SCROLL_ACTION);
+	g_signal_connect_swapped(action, "clamp-offset-y", G_CALLBACK(tangle_widget_clamp_child_boundaries), jammo_get_actor_by_id("fullsequencer-view-container"));
 
 	static_sequencer = JAMMO_SEQUENCER(jammo_get_object_by_id("fullsequencer-the-sequencer"));
 	static_metronome_track = jammo_metronome_track_new();
