@@ -15,6 +15,7 @@
 #include "../jammo-sample-button.h"
 #include "../jammo.h" //get_id
 
+#include "../../cem/cem.h"
 
 //Static pointers for loop rolls
 static ClutterActor* rhytmical_sample_looper;
@@ -75,26 +76,17 @@ Will return NULL in error cases
 */
 static JammoSample* get_centermost_sample_from_loop_roll(ClutterActor* wheel) {
 	gfloat y;
-	gfloat offset=0; //How much scroller is scrolled
+	gfloat offset=0,not_used; //How much scroller is scrolled
 	gfloat height;    //Height of the scroller (we take this from color_box behind samples)
-	TangleWidget* container;
 
-	//Wheels first actor is scroller
-	ClutterActor* scroller = clutter_actor_get_parent(wheel);
-	if (TANGLE_IS_SCROLLING_ACTOR(scroller)){
-		container = TANGLE_WIDGET(tangle_wrapper_actor_get_wrapped(TANGLE_WRAPPER_ACTOR(scroller)));
-		offset = tangle_scrolling_actor_get_scrolling_offset_y(TANGLE_SCROLLING_ACTOR(scroller));
-		//we are looking sample in SECOND slot
-		offset+= clutter_actor_get_height(tangle_widget_get_nth_child(container,0)); //we suppose all have same height
-		//printf("offset = %f\n",offset);
-	}
-	else {
-		printf("scroller was not parent of wheel\n");
-		return NULL;
-	}
+	ClutterAction* scroll_action = tangle_actor_get_action_by_type(wheel,TANGLE_TYPE_SCROLL_ACTION);
+	tangle_scroll_action_get_offsets(TANGLE_SCROLL_ACTION(scroll_action), &not_used,&offset);
+
+	//Check height of first sample-button, suppose all have same height
+	offset+= clutter_actor_get_height(tangle_widget_get_nth_child(TANGLE_WIDGET(wheel),0));
 
 	//Check height of the wheel
-	height = clutter_actor_get_height(CLUTTER_ACTOR(container));
+	height = clutter_actor_get_height(wheel);
 	//printf("height = %f\n",height);
 
 	//Check all sample button which one is closest to center (='offset')
@@ -102,7 +94,7 @@ static JammoSample* get_centermost_sample_from_loop_roll(ClutterActor* wheel) {
 	JammoSampleButton* closest = NULL;
 
 	GList* children;
-	for (children = tangle_widget_get_children_readonly(container); children; children = children->next) {
+	for (children = tangle_widget_get_children_readonly(TANGLE_WIDGET(wheel)); children; children = children->next) {
 		if (!JAMMO_IS_SAMPLE_BUTTON(children->data)){
 			//printf("this is not sample_button\n");  //Color_box triggers this at least
 			continue;
@@ -131,6 +123,7 @@ Functions for json
  * plays all samples from centerline of loop rolls
  */
 void fullsequencer_loop_arrow_clicked (TangleAction *action, GObject *source, const gchar *trigger, TangleProperties *properties){
+	cem_add_to_log("fullsequencer_play_all_loops-clicked",LOG_USER_ACTION);
 	//get_centermost_sample_from_loop_roll can return NULL (in error cases)
 	JammoSample* r = get_centermost_sample_from_loop_roll(rhytmical_sample_looper);
 	JammoSample* e = get_centermost_sample_from_loop_roll(effect_sample_looper);
