@@ -167,7 +167,7 @@ int create_mix_of_chain_composition(gpointer data) {
 		g_object_get(collaboration_chain_composition,"mix-location",&mix_location, NULL);		
 
 		// change sequencer to file mode
-		if (jammo_sequencer_file_mode(sequencer, mix_location)==0) {
+		if (jammo_sequencer_set_output_filename(sequencer, mix_location)==0) {
 			printf("sequencer changed to file mode successfully\n");
 		}
 
