@@ -40,7 +40,7 @@ typedef struct _JammoCollaborationGameClass {
 
 	void (*teacher_exit)();
 	int (*create_song_file)();
-	void (*game_callback)(GObject * game, int type);
+	void (*game_callback)(GObject * game, int type, const gchar* song_info);
 } JammoCollaborationGameClass;
 
 GType jammo_collaboration_game_get_type(void);
