@@ -108,6 +108,7 @@ void jammo_game_level_set_game_completed(JammoGameLevel* game_level, const gchar
 		game_data = (GameData*)game_data_in_list->data;
 		if (game_data->completed != is_completed) {
 			game_data->completed = is_completed;
+			g_object_notify(G_OBJECT(game_level), "games-completed");
 
 			if (game_data->completed && jammo_game_level_get_games_completed(game_level) >= g_list_length(game_level->priv->game_datas)) {
 				g_signal_emit(game_level, signals[COMPLETED], 0);
@@ -155,13 +156,11 @@ void jammo_game_level_start_game(JammoGameLevel* game_level, const gchar* game_n
 	} else {
 		game_data = (GameData*)game_data_in_list->data;
 		
-		if ((game_level->priv->script = tangle_object_get_script(TANGLE_OBJECT(game_level)))) {
-			g_object_ref(game_level->priv->script);
-		} else {
+		if (!game_level->priv->script) {
 			game_level->priv->script = clutter_script_new();
 		}
 
-		if (!(filename = tangle_object_lookup_filename(TANGLE_OBJECT(game_level), game_name))) {
+		if (!(filename = tangle_lookup_filename(game_name))) {
 			g_critical("Cannot find a JSON file '%s'.\n", game_name);
 		} else {
 			if (!(game_level->priv->script_id = clutter_script_load_from_file(game_level->priv->script, filename, &error))) {
@@ -347,6 +346,11 @@ static gboolean jammo_game_level_parse_custom_node(ClutterScriptable* scriptable
 	JsonNode* n;
 	
 	game_level = JAMMO_GAME_LEVEL(scriptable);
+	
+	if (!game_level->priv->script) {
+		game_level->priv->script = script;
+		g_object_ref(game_level->priv->script);
+	}
 
 	if (!strcmp(name, "games")) {
 		if (JSON_NODE_TYPE(node) != JSON_NODE_ARRAY) {
