@@ -104,8 +104,15 @@ void jammo_game_start(JammoGame* game) {
 	g_signal_emit(game, signals[STARTED], 0);
 }
 
-void jammo_game_complete(JammoGame* game) {
-	g_signal_emit(game, signals[COMPLETED], 0);
+void jammo_game_stop(JammoGame* game) {
+	GSList* slist_item;
+	ClutterActor* actor;
+
+	clutter_container_foreach(CLUTTER_CONTAINER(game->priv->view), CLUTTER_CALLBACK(clutter_actor_show), NULL);
+	for (slist_item = game->priv->disabled_actors; slist_item; slist_item = slist_item->next) {
+		actor = CLUTTER_ACTOR(slist_item->data);
+		jammo_chum_enable_all_actors(actor);
+	}
 }
 
 GList* jammo_game_get_tasks(JammoGame* game) {
@@ -168,7 +175,7 @@ void jammo_game_set_task_completed(JammoGame* game, const gchar* task_name, gboo
 				g_signal_emit(game, signals[TASK_COMPLETED], 0, task_name, tasks_completed);
 
 				if (tasks_completed >= game->priv->tasks_to_complete) {
-					jammo_game_complete(game);
+					g_signal_emit(game, signals[COMPLETED], 0);
 				}
 			}
 		}
