@@ -218,11 +218,11 @@ void jammo_miditrack_view_set_editing_enabled(JammoMiditrackView* miditrack_view
 	if (miditrack_view->priv->editing_enabled != editing_enabled) {
 		miditrack_view->priv->editing_enabled = editing_enabled;
 		
-		tangle_droppable_actor_set_dropping_enabled(TANGLE_DROPPABLE_ACTOR(miditrack_view), editing_enabled);
+		clutter_actor_meta_set_enabled(CLUTTER_ACTOR_META(tangle_actor_get_action_by_type(CLUTTER_ACTOR(miditrack_view), TANGLE_TYPE_DROP_ACTION)), editing_enabled);
 		for (children = tangle_widget_get_children_readonly(TANGLE_WIDGET(miditrack_view)); children; children = children->next) {
-			tangle_draggable_actor_set_dragging_enabled(TANGLE_DRAGGABLE_ACTOR(children->data), editing_enabled);
+			clutter_actor_meta_set_enabled(CLUTTER_ACTOR_META(tangle_actor_get_action_by_type(CLUTTER_ACTOR(children->data), TANGLE_TYPE_DRAG_ACTION)), editing_enabled);
 		}
-		
+
 		g_object_notify(G_OBJECT(miditrack_view), "editing-enabled");
 	}
 }
