@@ -13,7 +13,7 @@
 #include "../meam/jammo-sequencer.h"
 #include <string.h>
 
-G_DEFINE_TYPE(JammoSampleButton, jammo_sample_button, TANGLE_TYPE_DRAGGABLE_ACTOR);
+G_DEFINE_TYPE(JammoSampleButton, jammo_sample_button, TANGLE_TYPE_BUTTON);
 
 enum {
 	PROP_0,
@@ -23,7 +23,9 @@ enum {
 	PROP_SAMPLE_TYPE,
 	PROP_LOOP_ID,
 	PROP_TEXT,
-	PROP_SEQUENCER
+	PROP_SEQUENCER,
+	PROP_DRAG_THRESHOLD_X,
+	PROP_DRAG_THRESHOLD_Y
 };
 
 enum {
@@ -37,6 +39,7 @@ struct _JammoSampleButtonPrivate {
 	JammoSampleType sample_type;
 	gint loop_id;
 	JammoSequencer* sequencer;
+	ClutterAction* drag_action;
 };
 
 static const GEnumValue sample_type_values[] = {
@@ -60,6 +63,7 @@ GType jammo_sample_type_get_type(void) {
 
 static guint signals[LAST_SIGNAL] = { 0 };
 
+static void on_drag_end(ClutterDragAction* action, ClutterActor* actor, gfloat event_x, gfloat event_y, ClutterModifierType modifiers, gpointer user_data);
 static gboolean on_clicked(TangleButton* button, gpointer user_data);
 static void on_size_change(ClutterTexture* texture, gint width, gint height, gpointer user_data);
 static void set_sequencer(JammoSampleButton* sample_button, JammoSequencer* sequencer);
@@ -86,7 +90,7 @@ ClutterActor* jammo_sample_button_new_with_type_from_files(JammoSampleType sampl
 
 ClutterActor* jammo_sample_button_new_from_existing(JammoSampleButton* sample_button) {
 
-	return CLUTTER_ACTOR(g_object_new(JAMMO_TYPE_SAMPLE_BUTTON, "image-filename", sample_button->priv->image_filename, "sample", sample_button->priv->sample, "loop-id", sample_button->priv->loop_id, NULL));
+	return CLUTTER_ACTOR(g_object_new(JAMMO_TYPE_SAMPLE_BUTTON, "image-filename", sample_button->priv->image_filename, "sample", sample_button->priv->sample, "sample-type", sample_button->priv->sample_type, "loop-id", sample_button->priv->loop_id, NULL));
 }
 
 const gchar* jammo_sample_button_get_image_filename(JammoSampleButton* sample_button) {
@@ -129,7 +133,7 @@ void jammo_sample_button_set_image_filename(JammoSampleButton* sample_button, co
 			g_free(sample_button->priv->image_filename);
 			sample_button->priv->image_filename = NULL;
 		} else {
-			tangle_button_set_normal_background_actor(TANGLE_BUTTON(tangle_wrapper_actor_get_wrapped(TANGLE_WRAPPER_ACTOR(sample_button))), texture);
+			tangle_button_set_normal_background_actor(TANGLE_BUTTON(sample_button), texture);
 			g_signal_connect(texture, "size-change", G_CALLBACK(on_size_change), sample_button);
 		}
 
@@ -178,24 +182,11 @@ void jammo_sample_button_set_sample_type(JammoSampleButton* sample_button, Jammo
 	}
 }
 
-void jammo_sample_button_get_background_color(JammoSampleButton* sample_button, ClutterColor* background_color) {
-	tangle_widget_get_background_color(TANGLE_WIDGET(tangle_wrapper_actor_get_wrapped(TANGLE_WRAPPER_ACTOR(sample_button))), background_color);
-}
-
-gboolean jammo_sample_button_get_background_color_set(JammoSampleButton* sample_button) {
-
-	return tangle_widget_get_background_color_set(TANGLE_WIDGET(tangle_wrapper_actor_get_wrapped(TANGLE_WRAPPER_ACTOR(sample_button))));
-}
-
-void jammo_sample_button_set_background_color(JammoSampleButton* sample_button, const ClutterColor* background_color) {
-	tangle_widget_set_background_color(TANGLE_WIDGET(tangle_wrapper_actor_get_wrapped(TANGLE_WRAPPER_ACTOR(sample_button))), background_color);
-}
-
 const gchar* jammo_sample_button_get_text(JammoSampleButton* sample_button) {
 	const gchar* text = NULL;
 	ClutterActor* actor;
 	
-	if ((actor = tangle_widget_get_foreground_actor(TANGLE_WIDGET(tangle_wrapper_actor_get_wrapped(TANGLE_WRAPPER_ACTOR(sample_button))))) &&
+	if ((actor = tangle_widget_get_foreground_actor(TANGLE_WIDGET(sample_button))) &&
 	    CLUTTER_IS_TEXT(actor)) {
 		text = clutter_text_get_text(CLUTTER_TEXT(actor));
 	}
@@ -207,7 +198,7 @@ void jammo_sample_button_set_text(JammoSampleButton* sample_button, const gchar*
 	TangleWidget* widget;
 	ClutterActor* actor;
 
-	widget = TANGLE_WIDGET(tangle_wrapper_actor_get_wrapped(TANGLE_WRAPPER_ACTOR(sample_button)));
+	widget = TANGLE_WIDGET(sample_button);
 	if ((actor = tangle_widget_get_foreground_actor(widget))) {
 		g_return_if_fail(CLUTTER_IS_TEXT(actor));
 		
@@ -226,43 +217,25 @@ void jammo_sample_button_set_text(JammoSampleButton* sample_button, const gchar*
 	}
 }
 
-static gboolean jammo_sample_button_end_dragging(TangleDraggableActor* draggable_actor, TangleDragging* dragging) {
-	gboolean retvalue = FALSE;
+static void jammo_sample_button_constructed(GObject* object) {
 	JammoSampleButton* sample_button;
-	ClutterActor* parent;
-	ClutterActor* grand_parent;
 	
-	sample_button = JAMMO_SAMPLE_BUTTON(draggable_actor);
+	sample_button = JAMMO_SAMPLE_BUTTON(object);
 	
-	parent = clutter_actor_get_parent(CLUTTER_ACTOR(sample_button));
-	grand_parent = clutter_actor_get_parent(parent);
-	if (JAMMO_IS_TRACK_VIEW(grand_parent)) {
-		clutter_container_remove_actor(CLUTTER_CONTAINER(parent), CLUTTER_ACTOR(sample_button));
-	} else {
-		retvalue = TANGLE_DRAGGABLE_ACTOR_CLASS(jammo_sample_button_parent_class)->end_dragging(draggable_actor, dragging);
-	}
+	sample_button->priv->drag_action = tangle_drag_action_new();
+	g_signal_connect(sample_button->priv->drag_action, "drag-end", G_CALLBACK(on_drag_end), object);
+	clutter_actor_add_action(CLUTTER_ACTOR(object), sample_button->priv->drag_action);
 	
-	return retvalue;
-}
-
-static GObject* jammo_sample_button_constructor(GType type, guint n_construct_properties, GObjectConstructParam* construct_properties) {
-	GObject* object;
-	ClutterActor* button;
-
-	button = tangle_button_new();
-	tangle_widget_set_prefer_background_size(TANGLE_WIDGET(button), TRUE);
-
-	object = tangle_construct_with_extra_properties(G_OBJECT_CLASS(jammo_sample_button_parent_class)->constructor, type, n_construct_properties, construct_properties, "wrapped", button, NULL);
-
-	g_signal_connect(button, "clicked", G_CALLBACK(on_clicked), object);
-
-	return object;
+	tangle_widget_set_prefer_background_size(TANGLE_WIDGET(object), TRUE);
+	g_signal_connect(object, "clicked", G_CALLBACK(on_clicked), NULL);
 }
 
 static void jammo_sample_button_set_property(GObject* object, guint prop_id, const GValue* value, GParamSpec* pspec) {
 	JammoSampleButton* sample_button;
 	
 	sample_button = JAMMO_SAMPLE_BUTTON(object);
+	guint x_threshold;
+	guint y_threshold;
 
 	switch (prop_id) {
 		case PROP_IMAGE_FILENAME:
@@ -286,6 +259,19 @@ static void jammo_sample_button_set_property(GObject* object, guint prop_id, con
 		case PROP_SEQUENCER:
 			set_sequencer(sample_button, JAMMO_SEQUENCER(g_value_get_object(value)));
 			break;
+		case PROP_DRAG_THRESHOLD_X:
+			clutter_drag_action_get_drag_threshold (CLUTTER_DRAG_ACTION(sample_button->priv->drag_action),
+                                          &x_threshold,
+                                          &y_threshold);
+
+			clutter_drag_action_set_drag_threshold(CLUTTER_DRAG_ACTION(sample_button->priv->drag_action), g_value_get_uint(value),y_threshold);
+			break;
+		case PROP_DRAG_THRESHOLD_Y:
+			clutter_drag_action_get_drag_threshold (CLUTTER_DRAG_ACTION(sample_button->priv->drag_action),
+                                          &x_threshold,
+                                          &y_threshold);
+			clutter_drag_action_set_drag_threshold(CLUTTER_DRAG_ACTION(sample_button->priv->drag_action), x_threshold, g_value_get_uint(value));
+			break;
 		default:
 			G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
 			break;
@@ -296,6 +282,8 @@ static void jammo_sample_button_get_property(GObject* object, guint prop_id, GVa
         JammoSampleButton* sample_button;
 
 	sample_button = JAMMO_SAMPLE_BUTTON(object);
+	guint x_threshold;
+	guint y_threshold;
 
         switch (prop_id) {
 		case PROP_IMAGE_FILENAME:
@@ -316,6 +304,19 @@ static void jammo_sample_button_get_property(GObject* object, guint prop_id, GVa
 		case PROP_TEXT:
 			g_value_set_string(value, jammo_sample_button_get_text(sample_button));
 			break;
+		case PROP_DRAG_THRESHOLD_X:
+			clutter_drag_action_get_drag_threshold (CLUTTER_DRAG_ACTION(sample_button->priv->drag_action),
+                                          &x_threshold,
+                                          &y_threshold);
+
+			g_value_set_uint(value, x_threshold);
+			break;
+		case PROP_DRAG_THRESHOLD_Y:
+			clutter_drag_action_get_drag_threshold (CLUTTER_DRAG_ACTION(sample_button->priv->drag_action),
+                                          &x_threshold,
+                                          &y_threshold);
+			g_value_set_uint(value, y_threshold);
+			break;
 		default:
 		        G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
 		        break;
@@ -341,16 +342,13 @@ static void jammo_sample_button_dispose(GObject* object) {
 
 static void jammo_sample_button_class_init(JammoSampleButtonClass* sample_button_class) {
 	GObjectClass* gobject_class = G_OBJECT_CLASS(sample_button_class);
-	TangleDraggableActorClass* draggable_actor_class = TANGLE_DRAGGABLE_ACTOR_CLASS(sample_button_class);
 
-	gobject_class->constructor = jammo_sample_button_constructor;
+	gobject_class->constructed = jammo_sample_button_constructed;
 	gobject_class->finalize = jammo_sample_button_finalize;
 	gobject_class->dispose = jammo_sample_button_dispose;
 	gobject_class->set_property = jammo_sample_button_set_property;
 	gobject_class->get_property = jammo_sample_button_get_property;
 
-	draggable_actor_class->end_dragging = jammo_sample_button_end_dragging;
-
 	/**
 	 * JammoSampleButton:image-filename:
 	 */
@@ -425,6 +423,28 @@ static void jammo_sample_button_class_init(JammoSampleButtonClass* sample_button
 	                                "A sequencer that is used to track tempo and pitch until the underlying sample is added to an editing track",
 	                                JAMMO_TYPE_SEQUENCER,
 	                                G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK |G_PARAM_STATIC_BLURB));
+	/**
+	 * JammoSampleButton:drag-threshold-x:
+	 *
+	 * ClutterDragAction:drag-threshold-x.
+	 */
+	g_object_class_install_property(gobject_class, PROP_DRAG_THRESHOLD_X,
+	                                g_param_spec_uint("drag-threshold-x",
+	                                "Drag Threshold X",
+	                                "ClutterDragAction:drag-threshold-x",
+	                                0, G_MAXUINT, 0,
+	                                G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK |G_PARAM_STATIC_BLURB));
+	/**
+	 * JammoSampleButton:drag-threshold-y:
+	 *
+	 * ClutterDragAction:drag-threshold-y.
+	 */
+	g_object_class_install_property(gobject_class, PROP_DRAG_THRESHOLD_Y,
+	                                g_param_spec_uint("drag-threshold-y",
+	                                "Drag Threshold Y",
+	                                "ClutterDragAction:drag-threshold-y",
+	                                0, G_MAXUINT, 0,
+	                                G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK |G_PARAM_STATIC_BLURB));
 
 	/**
 	 * JammoSampleButton::listened:
@@ -445,6 +465,15 @@ static void jammo_sample_button_init(JammoSampleButton* sample_button) {
 	sample_button->priv = G_TYPE_INSTANCE_GET_PRIVATE(sample_button, JAMMO_TYPE_SAMPLE_BUTTON, JammoSampleButtonPrivate);
 }
 
+static void on_drag_end(ClutterDragAction* action, ClutterActor* actor, gfloat event_x, gfloat event_y, ClutterModifierType modifiers, gpointer user_data) {
+	ClutterActor* parent;
+	
+	parent = clutter_actor_get_parent(actor);
+	if (JAMMO_IS_TRACK_VIEW(parent)) {
+		clutter_container_remove_actor(CLUTTER_CONTAINER(parent), CLUTTER_ACTOR(actor));
+	}
+}
+
 static void on_stopped(JammoSample* sample, gpointer user_data) {
 	JammoSampleButton* sample_button;
 	
@@ -458,7 +487,7 @@ static void on_stopped(JammoSample* sample, gpointer user_data) {
 static gboolean on_clicked(TangleButton* button, gpointer user_data) {
 	JammoSampleButton* sample_button;
 	
-	sample_button = JAMMO_SAMPLE_BUTTON(user_data);
+	sample_button = JAMMO_SAMPLE_BUTTON(button);
 
 	jammo_sample_stop_all();
 	jammo_sample_play(sample_button->priv->sample);
@@ -473,7 +502,7 @@ static void on_size_change(ClutterTexture* texture, gint width, gint height, gpo
 	
 	sample_button = JAMMO_SAMPLE_BUTTON(user_data);
 	
-	tangle_actor_set_aspect_ratio(TANGLE_ACTOR(tangle_wrapper_actor_get_wrapped(TANGLE_WRAPPER_ACTOR(sample_button))), width / height);
+	tangle_actor_set_aspect_ratio(TANGLE_ACTOR(sample_button), width / height);
 }
 
 static void set_sequencer(JammoSampleButton* sample_button, JammoSequencer* sequencer) {
