@@ -24,6 +24,7 @@
 
 #include "configure.h"
 
+#include "../cem/cem.h"
 //used for commandline starting
 #include "3-6gui/chum.h"
 #include "7-12gui/midi_editor.h"
@@ -201,6 +202,11 @@ int main(int argc, char** argv) {
 	osso_context_t* osso_context;
 #endif
 
+	cem_set_log_level(LOG_DEBUG +LOG_INFO +LOG_FATAL +LOG_ERROR +LOG_WARN  +LOG_USER_ACTION +LOG_NETWORK +LOG_NETWORK_DEBUG);
+
+	gchar* message = g_strdup_printf("JamMo-%s started",VERSION);
+	cem_add_to_log(message, LOG_INFO);
+
 	TangleStylesheet* stylesheet;
 	gchar* filename;
 	ClutterActor* stage;
