@@ -2,12 +2,18 @@
 #ifndef CONFIG_H_
 #define CONFIG_H_
 
+#include "../configure.h"
+//SETS FULLSCREEN on/off  ...Must be TRUE for 800x480 resolutions
+#define SET_FULLSCREEN FALSE
+
+//USE JAMMOS CONFIGURATION.H
+#define PATH_DEVICE TRUE
+
+#define PG_IMAGES_DIR "/opt/jammo/password";
+#define INKML_FILE_PATH JAMMO_DIRECTORY "/motion_inkml.xml";
+#define PG_VERSION "v.0.4.1";
 
 #endif /* CONFIG_H_ */
 
 
-//SETS FULLSCREEN on/off  ...Must be TRUE for 800x480 resolutions
-#define SET_FULLSCREEN FALSE
 
-//SET 1 FOR 800x480 resolutions 0 otherwise ***** MUST BE FIXED
-#define PATH_DEVICE TRUE
