@@ -9,6 +9,9 @@
 #include <sstream>
 #include <fstream>
 #include <algorithm>
+#include <sys/types.h>
+#include <sys/stat.h>
+#include <unistd.h>
 #include "StorageAgent.h"
 
 
@@ -17,7 +20,11 @@ using namespace std;
 // Constructor
 StorageAgent::StorageAgent()
 {
-
+	struct stat st;
+	if(stat(JAMMOPROFILE,&st) != 0)
+	{
+		if(mkdir(JAMMOPROFILE,0777) == -1) std::cerr << "StorageAgent::StorageAgent: cannot create profile directory" << std::endl;
+	}
 }
 
 // Destructor
@@ -28,10 +35,10 @@ StorageAgent::~StorageAgent()
 }
 
 // Synchronizes profile data
-bool StorageAgent::Synchronize()
+gboolean StorageAgent::Synchronize()
 {
 	// TODO: Synchronizing missing
-	return true;
+	return TRUE;
 }
 
 // Removes the unneccesary lines from the files read
@@ -57,7 +64,7 @@ void StorageAgent::Tokenize(const string& str,
 }
 
 // Retrieves user profile data
-bool StorageAgent::Retrieve(int userID)
+gboolean StorageAgent::Retrieve(guint32 userID)
 {
 	// All the user information is currently saved to a 
 	// .csv file, so it is possible to save and edit
@@ -94,7 +101,7 @@ bool StorageAgent::Retrieve(int userID)
 		profileDetails[PROF_PARAM_LASTNAME] = PROF_PARAM_LASTNAME;
 		profileDetails[PROF_PARAM_POINTS] = "0";
 		profileDetails[PROF_PARAM_AGE] = "0";
-		return false;
+		return FALSE;
 	}
 
 	// Get the line and remove the ,
@@ -119,11 +126,11 @@ bool StorageAgent::Retrieve(int userID)
 	// Close the file
 	profileFile.close();
 
-	return true;
+	return TRUE;
 }
 
 // Stores user profile data
-bool StorageAgent::Store(int userID)
+gboolean StorageAgent::Store(guint32 userID)
 {
 	// TODO:  Store function for profile saving
 	// Since there is no real database yet, this
@@ -153,7 +160,7 @@ bool StorageAgent::Store(int userID)
 	{
 		//cerr << "Unable to open file!" << endl;	
 		// TODO report what kind of error
-		return false;
+		return FALSE;
 	}
 
 	// Save all the details to a string
@@ -170,7 +177,7 @@ bool StorageAgent::Store(int userID)
 	// and close the file
 	profileFile.close();
 
-	return true;
+	return TRUE;
 }
 
 string StorageAgent::getDetails()
@@ -201,14 +208,14 @@ string StorageAgent::getDetail(string& detail)
 	else return profileDetails[detail];
 }
 
-bool StorageAgent::setDetails(string& detail, string& newValue)
+gboolean StorageAgent::setDetails(string& detail, string& newValue)
 {
 	// The iterator goes through the profile details saved in the map
 	// If there is no detail the user tries to edit, it will inform the user
 	if ( (profileIterator = profileDetails.find(detail)) == profileDetails.end() )
 		{
 			//cout << "StorageAgent::setDetails: no " << detail << "-parameter" << endl;
-			return false;
+			return FALSE;
 		}
 	// Else change the detail to the new wanted value
 	else
@@ -216,13 +223,13 @@ bool StorageAgent::setDetails(string& detail, string& newValue)
 		profileDetails[detail] = newValue;
 	}
 
-	return true;
+	return TRUE;
 }
 
-bool StorageAgent::clearDetails()
+gboolean StorageAgent::clearDetails()
 {
 	// Clears the map to be empty
 	profileDetails.clear();
-	return true;
+	return TRUE;
 }
 
