@@ -538,8 +538,8 @@ gems_message* gems_create_message_collaboration_action_loop(gint16 type, guint l
 	*(gint16*)&msg->message[position] = g_htons(ACTION_LOOP);
 	position = position + sizeof(gint16);
 
-	//TODO change USER ID to real value
-	*(guint*)&msg->message[position] = g_htonl(0);
+	// User id 32 bits
+	*(guint*)&msg->message[position] = g_htonl(gems_profile_manager_get_userid(NULL));
 	position = position + sizeof(guint);
 
 	// TODO LOOP ID
@@ -582,9 +582,8 @@ gems_message* gems_create_message_collaboration_action_loop_sync(GList * list)
 	*(gint16*)&msg->message[position] = g_htons(ACTION_LOOP_SYNC);
 	position = position + sizeof(gint16);
 
-	//TODO change USER ID to real value
-	// 32 bits
-	*(guint*)&msg->message[position] = g_htonl(0);
+	// User id 32 bits
+	*(guint*)&msg->message[position] = g_htonl(gems_profile_manager_get_userid(NULL));
 	position = position + sizeof(guint);
 
 	// list, one loop is 8 bytes
@@ -627,9 +626,8 @@ gems_message* gems_create_message_collaboration_action_midi_series(gint16 type,
 	*(gint16*)&msg->message[position] = g_htons(ACTION_MIDI);
 	position = position + sizeof(gint16);
 
-	//TODO change USER ID to real value
-	// 32 bits
-	*(guint*)&msg->message[position] = g_htonl(0);
+	// User id 32 bits
+	*(guint*)&msg->message[position] = g_htonl(gems_profile_manager_get_userid(NULL));
 	position = position + sizeof(guint);
 
 	// TODO INSTRUMENT ID
@@ -683,9 +681,8 @@ gems_message* gems_create_message_collaboration_action_slider_series(gint16 type
 	*(gint16*)&msg->message[position] = g_htons(ACTION_SLIDER);
 	position = position + sizeof(gint16);
 
-	//TODO change USER ID to real value
-	// 32 bits
-	*(guint*)&msg->message[position] = g_htonl(0);
+	// User id 32 bits
+	*(guint*)&msg->message[position] = g_htonl(gems_profile_manager_get_userid(NULL));
 	position = position + sizeof(guint);
 
 	// TODO INSTRUMENT ID
