@@ -466,6 +466,15 @@ void gems_connection_localize_data_in_buffer(gems_connection* element)
 					gems_connection_add_16(element, g_ntohs(gems_connection_get_16(element, element->add_position)));
 					gems_connection_add_32(element, g_ntohl(gems_connection_get_32(element, element->add_position)));
 					break;
+				case ACTION_LOOP_SYNC:
+					gems_connection_add_32(element, g_ntohl(gems_connection_get_32(element, element->add_position)));
+					for (; element->add_position < gems_connection_get_32(element, 2);) {
+						// loop id
+						gems_connection_add_32(element, g_ntohl(gems_connection_get_32(element, element->add_position)));
+						// slot
+						gems_connection_add_32(element, g_ntohl(gems_connection_get_32(element, element->add_position)));
+					}
+					break;
 				case ACTION_MIDI:
 					gems_connection_add_32(element, g_ntohl(gems_connection_get_32(element, element->add_position)));
 					gems_connection_add_16(element, g_ntohs(gems_connection_get_16(element, element->add_position)));
