@@ -1251,7 +1251,7 @@ static void gst_jammo_slider_set_property (GObject * object, guint prop_id,
 			//realtime. There are no timestamp in event, use current time
 			if (src->recording){
 				//printf("realtime\n");
-				timestamp = src->time;
+				timestamp = src->time * src->tempo_scale;
 
 				if (event->type==JAMMO_SLIDER_EVENT_ON) {
 					process_slider_event_on(src, event->freq * pitch(src->pitch_shift));
