@@ -43,6 +43,8 @@ enum {
 struct _JammoInstrumentTrackPrivate {
 	GstElement* element;
 	int instrument_type;
+	gfloat tempo_scale;
+	gint pitch_shift;
 };
 
 
@@ -54,7 +56,9 @@ static guint signals[LAST_SIGNAL];
 
 
 JammoInstrumentTrack* jammo_instrument_track_new(JammoInstrumentType instrument_type) {
-	return JAMMO_INSTRUMENT_TRACK(g_object_new(JAMMO_TYPE_INSTRUMENT_TRACK,"instrument-type",instrument_type,NULL));
+	JammoInstrumentTrack * instrument_track = JAMMO_INSTRUMENT_TRACK(g_object_new(JAMMO_TYPE_INSTRUMENT_TRACK,"instrument-type",instrument_type,NULL));
+	instrument_track->priv->element=NULL;
+	return instrument_track;
 }
 
 static guint64 jammo_instrument_track_get_duration(JammoTrack* track) {
@@ -136,23 +140,21 @@ static gboolean jammo_instrument_track_receive_message(JammoTrack* track, GstMes
 
 static void jammo_instrument_track_set_tempo(JammoTrack* track, guint tempo) {
 	JammoInstrumentTrack* instrument_track;
-	gfloat tempo_scale;
 	
 	instrument_track = JAMMO_INSTRUMENT_TRACK(track);
-
 	if (tempo==0) {
-		tempo_scale=1.0;
+		instrument_track->priv->tempo_scale=1.0;
 	}
 	else {
-		tempo_scale=(gfloat)tempo / DEFAULT_TEMPO;
+		instrument_track->priv->tempo_scale=(gfloat)tempo / DEFAULT_TEMPO;
+	}
+	if (instrument_track->priv->element) {
+		g_object_set(instrument_track->priv->element, "tempo-scale", instrument_track->priv->tempo_scale, NULL);
 	}
-	g_object_set(instrument_track->priv->element, "tempo-scale", tempo_scale, NULL);
-	
 }
 
 static void jammo_instrument_track_set_pitch(JammoTrack* track, const gchar* pitch) {
 	JammoInstrumentTrack* instrument_track;
-	gint pitch_shift=0;
 	
 	instrument_track = JAMMO_INSTRUMENT_TRACK(track);
 
@@ -161,22 +163,24 @@ static void jammo_instrument_track_set_pitch(JammoTrack* track, const gchar* pit
 		return;
 	}
 
-	if (pitch==NULL) pitch_shift=0;
-	else if (strcmp(pitch, "C")==0) pitch_shift=0;
-	else if (strcmp(pitch, "C#")==0) pitch_shift=1;
-	else if (strcmp(pitch, "D")==0) pitch_shift=2;
-	else if (strcmp(pitch, "D#")==0) pitch_shift=3;
-	else if (strcmp(pitch, "E")==0) pitch_shift=4;
-	else if (strcmp(pitch, "F")==0) pitch_shift=5;
-	else if (strcmp(pitch, "F#")==0) pitch_shift=6;
-	else if (strcmp(pitch, "G")==0) pitch_shift=7;
-	else if (strcmp(pitch, "G#")==0) pitch_shift=8;
-	else if (strcmp(pitch, "A")==0) pitch_shift=9;
-	else if (strcmp(pitch, "A#")==0) pitch_shift=10;
-	else if (strcmp(pitch, "B")==0) pitch_shift=11;
-	else pitch_shift=0;
-	
-	g_object_set(instrument_track->priv->element, "pitch-shift", pitch_shift, NULL);	
+	if (pitch==NULL) instrument_track->priv->pitch_shift=0;
+	else if (strcmp(pitch, "C")==0) instrument_track->priv->pitch_shift=0;
+	else if (strcmp(pitch, "C#")==0) instrument_track->priv->pitch_shift=1;
+	else if (strcmp(pitch, "D")==0) instrument_track->priv->pitch_shift=2;
+	else if (strcmp(pitch, "D#")==0) instrument_track->priv->pitch_shift=3;
+	else if (strcmp(pitch, "E")==0) instrument_track->priv->pitch_shift=4;
+	else if (strcmp(pitch, "F")==0) instrument_track->priv->pitch_shift=5;
+	else if (strcmp(pitch, "F#")==0) instrument_track->priv->pitch_shift=6;
+	else if (strcmp(pitch, "G")==0) instrument_track->priv->pitch_shift=7;
+	else if (strcmp(pitch, "G#")==0) instrument_track->priv->pitch_shift=8;
+	else if (strcmp(pitch, "A")==0) instrument_track->priv->pitch_shift=9;
+	else if (strcmp(pitch, "A#")==0) instrument_track->priv->pitch_shift=10;
+	else if (strcmp(pitch, "B")==0) instrument_track->priv->pitch_shift=11;
+	else instrument_track->priv->pitch_shift=0;
+
+	if (instrument_track->priv->element) {
+		g_object_set(instrument_track->priv->element, "pitch-shift", instrument_track->priv->pitch_shift, NULL);
+	}
 }
 
 static GstElement* jammo_instrument_track_setup_playing_element(JammoPlayingTrack* playing_track, GstBin* bin) {
@@ -205,9 +209,14 @@ static GstElement* jammo_instrument_track_setup_playing_element(JammoPlayingTrac
 	if (instrument_nro==JAMMO_INSTRUMENT_TYPE_UD){
 			buffer=g_strdup_printf("%s%s",INSTRUMENT_FOLDER,"ud.txt");
 	}
+	if (instrument_nro==JAMMO_INSTRUMENT_TYPE_PIANO){
+			buffer=g_strdup_printf("%s%s",INSTRUMENT_FOLDER,"piano.txt");
+	}
 
 	g_object_set(G_OBJECT(instrument_track->priv->element), "init-instrument", buffer, NULL);
 	g_object_set(G_OBJECT(instrument_track->priv->element), "realtime", FALSE, NULL);
+	g_object_set(G_OBJECT(instrument_track->priv->element), "pitch-shift", instrument_track->priv->pitch_shift, NULL);
+	g_object_set(G_OBJECT(instrument_track->priv->element), "tempo-scale", instrument_track->priv->tempo_scale, NULL);
 	
 	gst_bin_add(bin, instrument_track->priv->element);
 
