@@ -41,8 +41,11 @@ struct _JammoTrackClass {
 	GInitiallyUnownedClass parent_class;
 	
 	guint64 (*get_duration)(JammoTrack* track);
-	GstElement* (*get_element)(JammoTrack* track);
-	void (*receive_message)(JammoTrack* track, GstMessage* message);
+	gboolean (*setup_element)(JammoTrack* track, GstBin* bin, GstElement* sink_element);
+	gboolean (*receive_message)(JammoTrack* track, GstMessage* message);
+	void (*set_tempo)(JammoTrack* track, guint tempo);
+	void (*set_pitch)(JammoTrack* track, const gchar* pitch);
+	void (*set_offline)(JammoTrack* track, gboolean offline);
 };
 
 GType jammo_track_get_type(void);
