@@ -7,7 +7,7 @@
 
 /* 
    install jammo-data. 
-     backing_track is: /opt/jammo/themes/rock_city/backing_track.wav
+     backing_track is: /opt/jammo/songs/easy/boat/vocal_fi.ogg
 
     recording is saved into /tmp/recording.wav
      or (N900) /home/user/.jammo/recording.wav
@@ -38,9 +38,11 @@ static void on_sequencer_stopped(JammoSequencer* sequencer, gpointer user_data)
 	jammo_sample_play(sample);
 }
 
+/*
 static void on_pitch_detected(JammoTrack* track, gfloat frequency, gpointer user_data) {
 	g_print("Frequency: %f\n", frequency);
 }
+*/
 
 static void on_duration_notify(GObject* object, GParamSpec* param_spec, gpointer user_data) {
 	guint64 duration;
@@ -61,13 +63,14 @@ int main(int argc, char** argv) {
 	sequencer = jammo_sequencer_new();
 	g_signal_connect(sequencer, "stopped", G_CALLBACK(on_sequencer_stopped), main_loop);
 
-	backing_track = jammo_backing_track_new("/opt/jammo/themes/city/110/backing_track.wav");
+	backing_track = jammo_backing_track_new("/opt/jammo/songs/easy/boat/vocal_fi.ogg");
 	g_signal_connect(backing_track, "notify::duration", G_CALLBACK(on_duration_notify), NULL);
 	jammo_sequencer_add_track(sequencer, JAMMO_TRACK(backing_track));
 	
-	recording_track = jammo_recording_track_new_with_pitch_detect(RECORDING_FILENAME);
+	/* recording_track = jammo_recording_track_new_with_pitch_detect(RECORDING_FILENAME); */
+	recording_track = jammo_recording_track_new(RECORDING_FILENAME);
 	jammo_sequencer_add_track(sequencer, JAMMO_TRACK(recording_track));
-	g_signal_connect(recording_track, "pitch-detected", G_CALLBACK(on_pitch_detected), NULL);
+	/* g_signal_connect(recording_track, "pitch-detected", G_CALLBACK(on_pitch_detected), NULL); */
 
 	g_print("Recording...\n");
 
